﻿-- ----------------------------------------------------------------------------
-- Grid2StatusIgnored by Potje
--       (Adapted from GridStatusIgnored written by Cyprias)
-- ----------------------------------------------------------------------------
local L = LibStub:GetLibrary("AceLocale-3.0"):GetLocale("Grid2")
local DBL = LibStub:GetLibrary("LibDBLayers-1.0")

-- Ignored is not in current locale list for grid2
-- L:RegisterTranslations("enUS", function() return {
	-- ["Ignored"] = true,
-- } end)

local Grid2StatusIGNORED = Grid2:NewModule("StatusIgnored")
local IGNORED = Grid2.statusPrototype:new("ignored")
local ignoredNames = {}

Grid2 = Grid2

function IGNORED:UpdateAllUnits()
        ignoredNames = {} --reset, maybe they removed someone.
        local iName
        for i=1, GetNumIgnores() do
                iName = GetIgnoreName(i)
                if iName then--would this ever not exist?
                        ignoredNames[iName] = true
                end
        end
        -- print("Hello, the number of ignored is", GetNumIgnores())
end

function IGNORED:OnEnable()
        self:RegisterEvent("IGNORELIST_UPDATE", "UpdateAllUnits")
        self:RegisterEvent("PARTY_MEMBERS_CHANGED", "UpdateAllUnits")
        self:RegisterEvent("RAID_ROSTER_UPDATE", "UpdateAllUnits")
end

function IGNORED:OnDisable()
        self:UnregisterEvent("IGNORELIST_UPDATE")
        self:UnregisterEvent("PARTY_MEMBERS_CHANGED")
        self:UnregisterEvent("RAID_ROSTER_UPDATE")
end

function IGNORED:IsActive(unitid)
        local name = GetUnitName(unitid)
        -- print("Being asked if", name, "is ignored. Answer is", ignoredNames[name])
        return ignoredNames[name];
end

function IGNORED:GetColor(unitid)
        local color = self.dbx.color1
        return color.r, color.g, color.b, color.a
end

function IGNORED:GetText(unitid)
        -- print("Being asked for text of", unitid, ". Answer is", L["Ignored"])
        return L["Ignored"]
end

local function Create(baseKey, dbx)
        Grid2:RegisterStatus(IGNORED, {"color", "text"}, baseKey, dbx)

        return IGNORED
end

Grid2.setupFunc["ignored"] = Create

-- if true then return end

-- Hook the loading of options so our associated lod options get loaded at the right time.
local prev_LoadOptions = Grid2.LoadOptions

function Grid2:LoadOptions(dblData, ...)
        local upgrade = prev_LoadOptions(self, dblData, ...)

        upgrade = DBL:LoadOptions("Grid2StatusIgnoredOptions", dblData, nil, "account", 1) or upgrade

        return upgrade
end

-- Hook UpgradeDefaults to blend in default options if current ones are old.
local prev_UpgradeDefaults = Grid2.UpgradeDefaults
function Grid2:UpgradeDefaults(dblData, ...)
        local flatten = prev_UpgradeDefaults(self, dblData, ...)

        local Grid2StatusIgnoredOptions = Grid2Options.plugins["Grid2StatusIgnoredOptions"]
        if (Grid2StatusIgnoredOptions) then
                flatten = DBL:UpgradeDefaults("Grid2StatusIgnoredOptions", dblData, Grid2StatusIgnoredOptions.UpgradeDefaults, "account", 1) or flatten
        end

        return flatten
end

